# load libraries
library(rags2ridges)
library(Rcpp)

# load implementation of 
# generalized ridge and lasso precision estimators 
sourceCpp("generalizedPfunctions.cpp")

# load data
load("lungTCGAdata.Rdata") 

# obtain (triangulated) support info
adjMat   <- cbind(rbind(matrix(1, 87, 87), diag(87)), rbind(diag(87), diag(87)))
zeros    <- which(adjMat==0, arr.ind=TRUE)
supportP <- support4ridgeP(nNodes=2*87, zeros=zeros)

# fit for the cancer group
Y0            <- cbind(t(GE0), t(CN0))
colnames(Y0)  <- NULL
rownames(Y0)  <- NULL
CVs           <- numeric()
lambdas       <- exp(seq(log(0.001), log(0.1), length.out=1000))
for (k in 1:length(lambdas)){
	lambdaMat <- matrix(lambdas[k], ncol(Y0), ncol(Y0))
	for (j in 1:nrow(zeros)){
		lambdaMat[zeros[j,1], zeros[j,2]]<- 10^(10)
	}
	CVs <- c(CVs, ridgePgen.kCV(lambdaMat, Y0, fold=5, target=matrix(0, ncol(Y0), ncol(Y0))))
	print(c(k, CVs[k]))
}
lambdasMat <- matrix(lambdas[which.min(CVs)], ncol(Y0), ncol(Y0))
for (j in 1:nrow(zeros)){
	lambdasMat[zeros[j,1], zeros[j,2]]<- 10^(10)
}
PzerosC    <- ridgePgen(covML(Y0), lambdasMat, target=PzerosC)
optLambdaC <- lambdas[which.min(CVs)]
CVresultsC <- cbind(lambdas, CVs)

# fit for the metastasis group
Y1           <- cbind(t(GE1), t(CN1))
colnames(Y1) <- NULL
rownames(Y1) <- NULL
CVs <- numeric()
lambdas <- exp(seq(log(0.001), log(100), length.out=100))
for (k in 1:length(lambdas)){
	lambdaMat <- matrix(lambdas[k], ncol(Y1), ncol(Y1))
	for (j in 1:nrow(zeros)){
		lambdaMat[zeros[j,1], zeros[j,2]]<- 10^(10)
	}
	CVs <- c(CVs, ridgePgen.kCV(lambdaMat, Y1, fold=5, target=PzerosC))
	print(c(k, CVs[k]))
}
lambdasMat <- matrix(lambdas[which.min(CVs)], ncol(Y1), ncol(Y1))
for (j in 1:nrow(zeros)){
	lambdasMat[zeros[j,1], zeros[j,2]]<- 10^(10)
}
PzerosM    <- ridgePgen(covML(Y1), lambdasMat, target=PzerosC)
optLambdaM <- lambdas[which.min(CVs)]
CVresultsM <- cbind(lambdas, CVs)


# code for plotting heatmaps and networks as before

